@@ -60,7 +60,9 @@
    ncks --jsn -C -m -v one_dmn_rec_var ~/nco/data/in_grp.nc
    ncks -O -4 --ppc ppc_dbl=1 --ppc ppc_flt,ppc_big=4 ~/nco/data/in.nc ~/foo.nc
    ncks -O --ppc ppc_dbl=1 --ppc '/g1/ppc.?',/g1/g1g1/ppc_dbl=4 ~/nco/data/in_grp.nc ~/foo.nc
-   ncks -O -m -M -v Snow_Cover_Monthly_CMG ${DATA}/hdf/MOD10CM.A2007001.005.2007108111758.hdf */
+   ncks -O -m -M -v Snow_Cover_Monthly_CMG ${DATA}/hdf/MOD10CM.A2007001.005.2007108111758.hdf
+   ncks -O ~/nco/data/in_zarr.nc "file://${HOME}/in_zarr#mode=nczarr,file"
+   ncks -O ~/nco/data/in_zarr4.nc "file://${HOME}/in_zarr4#mode=nczarr,file" */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h> /* Autotools tokens */
@@ -137,6 +139,7 @@ main(int argc,char **argv)
   char *fl_in=NULL;
   char *fl_in_dpl=NULL; /* [sng] Duplicate of fl_in */
   char *fl_in_stub=NULL; /* [sng] Filename component of fl_in */
+  char *fl_in_frg=NULL; /* [sng] Location of fragment component (e.g., "mode=") of fl_in */
   char *fl_out=NULL; /* Option o */
   char *fl_out_tmp=NULL_CEWI;
   char *fl_prn=NULL; /* [sng] Formatted text output file */
@@ -248,8 +251,9 @@ main(int argc,char **argv)
   nco_bool EXTRACT_ASSOCIATED_COORDINATES=True; /* Option C */
   nco_bool EXTRACT_CLL_MSR=True; /* [flg] Extract cell_measures variables */
   nco_bool EXTRACT_FRM_TRM=True; /* [flg] Extract formula_terms variables */
-  nco_bool FL_RTR_RMT_LCN;
+  nco_bool FL_LST_IN_APPEND=True; /* [flg] Option H */
   nco_bool FL_LST_IN_FROM_STDIN=False; /* [flg] fl_lst_in comes from stdin */
+  nco_bool FL_RTR_RMT_LCN;
   nco_bool FORCE_APPEND=False; /* Option A */
   nco_bool FORCE_NOCLOBBER=False; /* Option no-clobber */
   nco_bool FORCE_OVERWRITE=False; /* Option O */
@@ -556,6 +560,8 @@ main(int argc,char **argv)
     {"gpe",required_argument,0,'G'}, /* [sng] Group Path Edit (GPE) */
     {"grp",required_argument,0,'g'},
     {"group",required_argument,0,'g'},
+    {"fl_lst_in",no_argument,0,'H'},
+    {"file_list",no_argument,0,'H'},
     {"history",no_argument,0,'h'},
     {"hst",no_argument,0,'h'},
     {"hieronymus",no_argument,0,'H'}, /* fxm: need better mnemonic for -H */
@@ -1124,6 +1130,10 @@ main(int argc,char **argv)
 #endif /* !WIN32 */
   fl_in_stub=strrchr(fl_in_dpl,sls_chr);
   if(fl_in_stub) fl_in_stub++; else fl_in_stub=fl_in_dpl;
+  fl_in_frg=strstr(fl_in_stub,"#mode");
+  if(fl_in_frg) *fl_in_frg='\0';
+  //(void)fprintf(stderr,"%s: DEBUG quark main() reports fl_lst_in=%s, fl_in=%s, fl_pth_lcl=%s, fl_in_frg=%s, fl_in_stub=%s\n",nco_prg_nm_get(),fl_lst_in[0],fl_in,fl_pth_lcl,fl_in_frg,fl_in_stub);
+
   /* Open file using appropriate buffer size hints and verbosity */
   if(RAM_OPEN) md_open=NC_NOWRITE|NC_DISKLESS; else md_open=NC_NOWRITE;
   if(SHARE_OPEN) md_open=md_open|NC_SHARE;
@@ -1306,6 +1316,8 @@ main(int argc,char **argv)
       if(HISTORY_APPEND && FORCE_APPEND) (void)nco_prv_att_cat(fl_in,in_id,out_id);
       if(gaa_nbr > 0) (void)nco_glb_att_add(out_id,gaa_arg,gaa_nbr);
       if(HISTORY_APPEND) (void)nco_vrs_att_cat(out_id);
+      if(HISTORY_APPEND && FL_LST_IN_APPEND && FL_LST_IN_FROM_STDIN) (void)nco_fl_lst_att_cat(out_id,fl_lst_in,fl_nbr);
+
 #ifdef ENABLE_MPI
       if(prc_rnk == rnk_mgr)
 	if(prc_nbr > 0 && HISTORY_APPEND) (void)nco_mpi_att_cat(out_id,prc_nbr);
